@@ -40,14 +40,12 @@ class InvenioSearchUI(object):
         :param app: The Flask application.
         """
         app.config.setdefault(
-            'SEARCH_UI_BASE_TEMPLATE',
-            app.config.get('BASE_TEMPLATE', 'invenio_search_ui/base.html')
+            'SEARCH_UI_BASE_TEMPLATE', app.config.get('BASE_TEMPLATE')
         )
         app.config.setdefault(
-            'SEARCH_UI_HEADER_TEMPLATE',
-            app.config.get('HEADER_TEMPLATE',
-                           'invenio_search_ui/base_header.html')
+            'SEARCH_UI_HEADER_TEMPLATE', app.config.get('HEADER_TEMPLATE')
         )
+
         for k in dir(config):
             if k.startswith('SEARCH_UI_'):
                 app.config.setdefault(k, getattr(config, k))
